from typing import List
from pydantic import BaseModel


class PostProcessor(BaseModel):
    url: str
    email: List[str]


class Credentials(BaseModel):
    project_id: str
    private_key: str
    token_uri: str
    client_email: str
    client_id: str
    auth_uri: str
    auth_provider_x509_cert_url: str
    private_key_id: str
    client_x509_cert_url: str
    type: str


class GsttConfigs(BaseModel):
    gcs_bucket: str
    credentials: Credentials


class GenerateCaptions(BaseModel):
    enabled: bool
    gstt_configs: GsttConfigs


class Docker(BaseModel):
    image: str
    private_image: bool
    privileged_image: bool


class _Mapsor(BaseModel):
    aerender_cloud_provider: str
    docker: Docker
    memory: int
    vcpus: int
    janus_cloud_provider: str
    janus_queue: str
    xmorph_api: str
    aerender_queue: str
    janus_tag: str
    queue: str
    aerender_debug_mode: bool
    region: str
    aerender_tag: str
    cloud: str
    mapsor_api: str
    token: str


class Previews(BaseModel):
    aspect_ratio: str
    disable_hlsv4: bool


class Sts(BaseModel):
    assume_role: str
    external_id: str


class AudioNormalisation(BaseModel):
    enabled: bool
    target: int
    enabled_types: List


class ValidateIdrInterval(BaseModel):
    run: bool
    threshold: int


class MediaQc(BaseModel):
    lang_codes_to_skip: List
    validate_idr_interval: ValidateIdrInterval
    continuity_check_threshold: int


class MetaValidations(BaseModel):
    skip_segments: str
    segments: bool
    custom_keys: str
    skip_custom_keys: str
    skip_aspect_ratio: str
    aspect_ratio: bool
    skip_segments_for_types: List
    tc_in: bool
    skip_tc_in: str
    regions: bool


class UiUpload(BaseModel):
    assume_role: str
    external_id: str


class AccountConfig(BaseModel):
    karma_url: str | None
    enable_karma: bool
    karma_secret: str | None
    enable_cdn: bool
    headend_auto_register: bool
    post_processor: PostProcessor
    generate_captions: GenerateCaptions | None
    mapsor: _Mapsor
    ui_metadata_keys: List[str]
    previews: Previews
    sts: Sts
    audio_normalisation: AudioNormalisation
    lambda_arn: str
    media_qc: MediaQc | None
    meta_validations: MetaValidations
    ui_upload: UiUpload
